@@ -39,6 +39,7 @@
 #define UPDATE_TAU                    5     /* seconds */    
 #define MAX_UPDATES_PER_TAU           15    /* HZ */    
 #define TOOLTIP_DELAY                 300   /* ms */
+#define MSGLEN                        256   /* characters */
 
 /* variables */
 static Monitor *monitor;
@@ -77,11 +78,12 @@ static GkrellmTicks *GKp;
 /* global exclusion_expression variable */
 extern regex_t *exclusion_expression;
 extern gint exclusionchanged;
-static gchar s_exclusion [255]; //string to exclude rexexp from proc list
+static gchar s_exclusion [MSGLEN]; //string to exclude rexexp from proc list
 /* global show_nice_processes variable */
 extern int show_nice_processes;
 extern enum modes pluginMode;
-static gchar tooltip_text[256]; //will hold the tooltip onmouseover
+static gchar tooltip_text[MSGLEN]; //will hold the tooltip onmouseover
+
 int show_percent;
 int tokill_i;
 int tokill_pid;
@@ -97,9 +99,9 @@ static struct process   cache_best[MAXITEMS];
 static gint             cache_ntop;
 static gboolean         gkrelltop_server_available;
 
-static gint             gkrelltopd_version_major,
-                        gkrelltopd_version_minor,
-                        gkrelltopd_version_rev;
+static gint             gkrelltopd_version_major;
+static gint             gkrelltopd_version_minor;
+static gint             gkrelltopd_version_rev;
 
 static void top_client_setup(gchar *line)
 {
@@ -113,7 +115,7 @@ static void top_client_setup(gchar *line)
 /* show numproc panels and hide the other MAXITEMS-numproc panels */
 static void check_numproc()
 {
-    int i;
+    gint i;
     for (i=0;i<numproc;i++) {
         gkrellm_panel_show( entry[i].panel );
     }
@@ -142,8 +144,8 @@ static void top_client_data_from_server(gchar *line)
                 cache_best[n].amount = 0;
                 cache_best[n].pid = 0;
             }
-        }
-    else if (   !strcmp(which, "best")
+    }
+    else if( !strcmp(which, "best")
           && sscanf(item, "%d %127s %d %f", &n, name, &pid, &amount) == 4
           && n >= 0 && n < MAXITEMS)
     {
@@ -155,7 +157,7 @@ static void top_client_data_from_server(gchar *line)
 
 static gint gkrelltop_client_process_find_top_three(struct process **best)
 {
-    gint    i;
+    gint i;
 
     for (i = 0; i < numproc; ++i)
         best[i] = &cache_best[i];
@@ -167,7 +169,8 @@ static gint gkrelltop_client_process_find_top_three(struct process **best)
 
 
 /* gets called everytime the panel gets refreshed if it was covered */
-static gint top_expose_event(GtkWidget * widget, GdkEventExpose * ev, Panel *panel)
+static gint top_expose_event(GtkWidget * widget, 
+               GdkEventExpose * ev, Panel *panel)
 {
     gdk_draw_pixmap(widget->window,
         widget->style->fg_gc[GTK_WIDGET_STATE(widget)],
@@ -178,7 +181,7 @@ static gint top_expose_event(GtkWidget * widget, GdkEventExpose * ev, Panel *pan
 
 /* upon signal enter_notify_event */
 static void top_enter_notify_event(GtkWidget * widget, 
-                GdkEventCrossing * event, gpointer user_data)
+            GdkEventCrossing * event, gpointer user_data)
 { 
     mouseIn=GPOINTER_TO_INT(user_data); /* mark where mouse moved into */
     display_tooltip=TRUE; /* redisplay */
@@ -188,15 +191,15 @@ static void top_enter_notify_event(GtkWidget * widget,
 }
 
 /* upon signal motion_notify_event */
-static void top_motion_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-        gpointer user_data)
+static void top_motion_notify_event(GtkWidget * widget, 
+                GdkEventCrossing * event, gpointer user_data)
 {
     display_tooltip=TRUE; /* redisplay */
 }
 
 /* upon signal leave_notify_event */
-static void top_leave_notify_event(GtkWidget * widget, GdkEventCrossing * event,
-        gpointer user_data)
+static void top_leave_notify_event(GtkWidget * widget, 
+            GdkEventCrossing * event, gpointer user_data)
 {
     mouseIn = -1;        /* change status; mouse is outside */
 }
@@ -206,6 +209,9 @@ static void top_ok_dialog(GtkWidget *widget, GtkWidget *dialog)
     /* at this point send the signal to tokill_pid even though 
      * it might not hold anymore that
      *    (best[tokill_i] && best[tokill_i]->pid == tokill_pid) 
+     * that is it might not hold that it is the most active process anylonger
+     * it might be a better idea to copy it in the framebuffer and the 
+     * user kills it from a terminal.
      */
     kill(tokill_pid,9);
 
@@ -224,18 +230,18 @@ static void top_message_dialog()
     GtkWidget   *vbox;
     GtkWidget   *hbox, *button;
     GtkWidget   *label;
-    gchar        message[256];
+    gchar        message[MSGLEN];
 
     /* if it has changed in the mean time */
     if(!best[tokill_i] || best[tokill_i]->pid != tokill_pid) 
         return;
 
-    snprintf(message,sizeof(message),"Kill process %s with pid %d?",best[tokill_i]->name,best[tokill_i]->pid);
+    snprintf(message,sizeof(message),"Kill process %s with pid %d?",
+                            best[tokill_i]->name,best[tokill_i]->pid);
 
     dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title(GTK_WINDOW(dialog), "Kill process");
-    gtk_window_set_wmclass(GTK_WINDOW(dialog),
-                "Gkrellm_dialog", "Gkrellm");
+    gtk_window_set_wmclass(GTK_WINDOW(dialog), "Gkrellm_dialog", "Gkrellm");
 
     vbox = gtk_vbox_new(FALSE, 0);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 8);
@@ -294,8 +300,8 @@ static void top_update_panels()
 {
     gchar display_text[64];
 
-    int i = 0;
-    int n;
+    gint i = 0;
+    gint n;
 
     bzero(display_text,sizeof(display_text));
 
@@ -335,24 +341,26 @@ static void top_update_panels()
             break; //the next for will fill in with blanks
 
         if(show_percent)
-            snprintf(display_text, sizeof(display_text),"%.0f%c %s", best[i]->amount,'%',best[i]->name);
+            snprintf(display_text, sizeof(display_text),
+                "%.0f%c %s", best[i]->amount,'%',best[i]->name);
         else 
             snprintf(display_text, sizeof(display_text)," %s", best[i]->name);
 
-        char ch = (i < n-1) ? '\n' : ' ' ; /* prnt \n only for 1 and 2*/
-        char tmp[256];
+        gchar ch = (i < n-1) ? '\n' : ' ' ; /* prnt \n only for 1 and 2*/
+        gchar tmp[MSGLEN];
         snprintf(tmp,sizeof(tmp), "%d: %4.1f%c  %6.2d  %.30s%c", 
-            i+1, best[i]->amount, '%', best[i]->pid, 
-            best[i]->name, ch);
+            i+1, best[i]->amount, '%', best[i]->pid, best[i]->name, ch);
 
         if(display_tooltip) /* append at the end of tooltip_text */
             strncat(tooltip_text,tmp,sizeof(tooltip_text)-strlen(tooltip_text));
 
         /* set the panels with the top three processes */
-        gkrellm_draw_decal_text(entry[i].panel, entry[i].decal_text,display_text, 0);
+        gkrellm_draw_decal_text(entry[i].panel, 
+            entry[i].decal_text,display_text, 0);
+
         /* best[i]->amount determines the ofset in the pixmap */
         gkrellm_update_krell(entry[i].panel, 
-                             entry[i].krell_meter, best[i]->amount ); 
+            entry[i].krell_meter, best[i]->amount ); 
     } // end for
     for(;i<numproc;i++) { //take care of the rest of the entries, 
                           //i set in the previous for loop
@@ -366,7 +374,7 @@ static void top_update_panels()
     if (mouseIn >= 0 && display_tooltip) { 
         /* display  tooltip */
        gtk_tooltips_set_tip(panel_tooltip, entry[mouseIn].panel->drawing_area,
-                             tooltip_text, tooltip_text); 
+                                                   tooltip_text, tooltip_text); 
     }
 
     //draw the newly updated pannel
@@ -392,7 +400,7 @@ static void recompute_modulus()
         else 
             global_update_HZ = MAX_UPDATES_PER_TAU;
 
-        master_modulus=(int)(global_update_HZ*UPDATE_TAU/local_updates);
+        master_modulus=(gint)(global_update_HZ*UPDATE_TAU/local_updates);
         if(master_modulus<1) master_modulus=1;
     }
 }
@@ -433,7 +441,8 @@ static void top_update_plugin()
             global_update_HZ=5;
     }
 
-    if ((GK.timer_ticks % (int)(global_update_HZ*UPDATE_TAU)) == local_updates){
+    if ((GK.timer_ticks % (gint)(global_update_HZ*UPDATE_TAU)) == local_updates)
+    {
         top_update_panels();  /* update the panels */
     }   //if gk.second_tick
 #endif
@@ -476,7 +485,7 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
     for (i=0; i<MAXITEMS; i++) {
 
         /* create the krell--the image with the color */
-        entry[i].krell_meter = gkrellm_create_krell(entry[i].panel, image, style);
+        entry[i].krell_meter = gkrellm_create_krell(entry[i].panel,image,style);
         gkrellm_set_krell_full_scale(entry[i].krell_meter, 100, 1);
         gkrellm_monotonic_krell_values(entry[i].krell_meter, FALSE);
         //update the panel with the new meters
@@ -486,7 +495,8 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
          * the full panel width (minus the margins).  Position it at top border
          * y=2 and left margin x=-1 of the style.
          */
-        entry[i].decal_text = gkrellm_create_decal_text(entry[i].panel, "Ayl0",ts,style,-1,2,-1);
+        entry[i].decal_text = gkrellm_create_decal_text(entry[i].panel, 
+                                                    "Ayl0",ts,style,-1,2,-1);
 
         y=entry[i].decal_text->y+entry[i].decal_text->h-3;
 
@@ -505,30 +515,39 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
 
 
     /* connect the signals */
+    
     if (first_create) {
-     for (i=0; i<MAXITEMS; i++) {
-       gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area), 
+        
+      for (i=0; i<MAXITEMS; i++) {
+        gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area), 
           "expose_event", (GtkSignalFunc) top_expose_event, entry[i].panel);
-       gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
+
+        gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
           "enter_notify_event", (GtkSignalFunc) top_enter_notify_event, 
                 GINT_TO_POINTER(i));
-       gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
-          "leave_notify_event", (GtkSignalFunc) top_leave_notify_event, NULL);
-       gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
-        "motion_notify_event" ,(GtkSignalFunc) top_motion_notify_event, NULL);
 
-       gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
+        gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
+          "leave_notify_event", (GtkSignalFunc) top_leave_notify_event, NULL);
+
+        gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
+          "motion_notify_event" ,(GtkSignalFunc) top_motion_notify_event, NULL);
+
+        
+        gtk_signal_connect(GTK_OBJECT(entry[i].panel->drawing_area),
             "button_press_event", (GtkSignalFunc) top_click_event, 
                 GINT_TO_POINTER(i));
-     }
+      }
 
-     panel_tooltip = gtk_tooltips_new();
+      panel_tooltip = gtk_tooltips_new();
     }
 
 
-    for (i=0; i<MAXITEMS; i++) {
+    for (i=0; i<MAXITEMS; i++) 
+    {
         /* start with empty string */
-        gtk_tooltips_set_tip(panel_tooltip, entry[i].panel->drawing_area," \n \n ", "");
+        gtk_tooltips_set_tip(panel_tooltip, 
+            entry[i].panel->drawing_area," \n \n ", "");
+
         gtk_tooltips_set_delay(panel_tooltip, TOOLTIP_DELAY);
         gtk_tooltips_enable(panel_tooltip);
 
@@ -539,7 +558,7 @@ static void top_create_plugin(GtkWidget * vbox, gint first_create)
     /* set the local_updates after reading from the config */
     if(local_updates > MAX_UPDATES_PER_TAU) 
         local_updates = MAX_UPDATES_PER_TAU;
-    if(local_updates <= 0) 
+    else if(local_updates <= 0) 
         local_updates = 1; 
 
     recompute_modulus();
@@ -573,20 +592,23 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Number of top processes to show (max 3):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_numproc, (gfloat) numproc, 1.0, MAXITEMS, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
+    gkrellm_spin_button(hbox, &g_numproc, (gfloat) numproc, 1.0, 
+             MAXITEMS, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
 
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Show only processes above (in %):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_threshold, (gfloat) threshold, 0.0, 100.0, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
+    gkrellm_spin_button(hbox, &g_threshold, (gfloat) threshold, 
+           0.0, 100.0, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
     label = gtk_label_new(_("Frequency of updates (in 5 seconds):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-    gkrellm_spin_button(hbox, &g_updates, (gfloat) local_updates, 1.0, MAX_UPDATES_PER_TAU, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
+    gkrellm_spin_button(hbox, &g_updates, (gfloat) local_updates, 1.0, 
+            MAX_UPDATES_PER_TAU, 1.0, 5.0, 0, 60, NULL, NULL, FALSE, _(""));
 
 
     /* exclusions stuff */
@@ -594,6 +616,7 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     label = gtk_label_new(_("Exclusions (as regular expression ex: ^idle) : "));
     gtk_box_pack_start(GTK_BOX(hbox),label,TRUE,TRUE,0);
     g_exclusions = gtk_entry_new();
+
     if (strlen(s_exclusion) > 0)
         gtk_entry_set_text((GtkEntry*)g_exclusions, s_exclusion);
 
@@ -620,12 +643,13 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
 
     /* -- About -- */
     about_text = g_strdup_printf(
-      "gkrelltop version 2.2.10\n"
+      "gkrelltop version 2.2.11\n"
       "gkrellm top plugin\n"
       "Copyright (c) 2007 Adi Zaimi\n"
       "adizaimi@users.sourceforge.net\n"
       "http://gkrelltop.sourceforge.net\n\n"
       "Released under the GNU Public License");
+
     text = gtk_label_new(about_text);
     label = gtk_label_new("About");
     gtk_notebook_append_page(GTK_NOTEBOOK(tabs),text,label);
@@ -634,6 +658,19 @@ static void top_create_plugin_tab(GtkWidget *tab_vbox)
     return;
 }
 
+static void top_apply_exclusion() 
+{
+    if( strlen(s_exclusion) > 0 ) {
+        static regex_t reg;
+        exclusion_expression = &reg;
+        regcomp(exclusion_expression, s_exclusion, REG_EXTENDED);
+        exclusionchanged=1;
+    }
+    else if(exclusion_expression){
+        exclusion_expression=0;
+        exclusionchanged=1;
+    }
+}
 
 static void top_apply_config() 
 {
@@ -655,27 +692,22 @@ static void top_apply_config()
     local_updates = gtk_spin_button_get_value_as_int(spin);
 
     //if the exclusions is set, build the exclusion_expression variable
-    if (g_exclusions ) {
-       g_strlcpy(s_exclusion, gtk_entry_get_text((GtkEntry *) g_exclusions),
-                                                         sizeof(s_exclusion));
-       if( strlen(s_exclusion) > 0 ) {
-           static regex_t reg;
-           exclusion_expression = &reg;
-           regcomp(exclusion_expression, s_exclusion, REG_EXTENDED);
-           exclusionchanged=1;
-       }
-       else if(exclusion_expression){
-           exclusion_expression=0;
-       }
+    if (g_exclusions ) 
+    {
+        
+        g_strlcpy(s_exclusion, gtk_entry_get_text((GtkEntry *) g_exclusions),
+                                                         sizeof(s_exclusion) );
+        top_apply_exclusion();
     }
-    else if (exclusion_expression){
-       exclusion_expression=0;
+    else if (exclusion_expression)
+    {
+        exclusion_expression=0;
     }
 
     /* safety check */
     if(local_updates > MAX_UPDATES_PER_TAU) 
         local_updates = MAX_UPDATES_PER_TAU;
-    if(local_updates <= 0) 
+    else if(local_updates <= 0) 
         local_updates = 1; 
 
     recompute_modulus();
@@ -691,10 +723,14 @@ static void top_save_config(FILE *f)
 
     fprintf(f, "%s numproc %d\n", PLUGIN_CONFIG_KEYWORD, numproc);
     fprintf(f, "%s threshold %d\n", PLUGIN_CONFIG_KEYWORD, threshold);
-    fprintf(f, "%s show_nice_processes %d\n", PLUGIN_CONFIG_KEYWORD, show_nice_processes);
+    fprintf(f, "%s show_nice_processes %d\n", 
+            PLUGIN_CONFIG_KEYWORD, show_nice_processes);
+
     fprintf(f, "%s show_percent %d\n", PLUGIN_CONFIG_KEYWORD, show_percent);
     fprintf(f, "%s local_updates %d\n", PLUGIN_CONFIG_KEYWORD, local_updates);
-    fprintf(f, "%s exclusion_expression %s\n", PLUGIN_CONFIG_KEYWORD, s_exclusion);
+    fprintf(f, "%s exclusion_expression %s\n", 
+            PLUGIN_CONFIG_KEYWORD, s_exclusion);
+
     return;
 }
 
@@ -703,8 +739,8 @@ static void top_load_config(gchar *config_line)
     gchar   config_keyword[32], config_data[CFG_BUFSIZE];
     gint    n;
 
-    if ((n = sscanf(config_line, "%31s %[^\n]", config_keyword, 
-                                                   config_data)) != 2) {
+    if ((n = sscanf(config_line,"%31s %[^\n]",config_keyword,config_data)) != 2)
+    {
         return;
     }
 
@@ -725,6 +761,7 @@ static void top_load_config(gchar *config_line)
     }
     else if (strcmp(config_keyword, "exclusion_expression")==0) {
         sscanf(config_data, "%s", s_exclusion);
+        top_apply_exclusion();
     }
 
     return;
@@ -763,14 +800,14 @@ Monitor *init_plugin()
 
     if (gkrelltop_server_available)
     {
-       find_top_three = gkrelltop_client_process_find_top_three;
-       gkrellm_client_plugin_serve_data_connect(&top_plugin_mon,
-       GKRELLTOP_SERVE_NAME, top_client_data_from_server);
+        find_top_three = gkrelltop_client_process_find_top_three;
+        gkrellm_client_plugin_serve_data_connect(&top_plugin_mon,
+        GKRELLTOP_SERVE_NAME, top_client_data_from_server);
     }
     else
-       find_top_three = gkrelltop_process_find_top_three;
+        find_top_three = gkrelltop_process_find_top_three;
 #else
-       find_top_three = gkrelltop_process_find_top_three;
+        find_top_three = gkrelltop_process_find_top_three;
 #endif
 
     monitor = &top_plugin_mon;
